pub enum Flush {
Auto,
Flush,
NoFlush,
}Expand description
How the decoder should handle flushing.
The behavior of flushing is somewhat unclear upstream. If you run into decoder errors,
you should probably disable automatic flushing, and manually call Decoder::flush_remaining
after all NAL units have been processed. It might be a good idea to do the latter regardless.
If you have more info on flushing best practices, we’d greatly appreciate a PR to make our decoding pipeline more robust.
Variants
Auto
Uses the current currently configured decoder default (which is attempted flushing after each decode).
Flush
Flushes after each decode operation.
NoFlush
Do not flush after decode operations.