pub struct DecoderConfig { /* private fields */ }Expand description
Configuration for the Decoder.
Setting missing? Please file a PR!
Implementations
Sourceimpl DecoderConfig
impl DecoderConfig
Sourcepub const unsafe fn num_threads(self, num_threads: u32) -> Self
pub const unsafe fn num_threads(self, num_threads: u32) -> Self
Sets the number of threads; will probably segfault the decoder, see below.⚠️
Safety
This setting might work on some platforms but will probably just segfault. Consider this a highly experimental option we only expose to test if and where threading actually works. Ultimately you should consult with the upstream OpenH264 project where and when it is safe to set this.
See this issue for details.
Sourcepub const fn debug(self, value: bool) -> Self
pub const fn debug(self, value: bool) -> Self
Enables detailed console logging inside OpenH264.
Sourcepub const fn flush_after_decode(self, flush_behavior: Flush) -> Self
pub const fn flush_after_decode(self, flush_behavior: Flush) -> Self
Sets the default flush behavior after decode operations..